@@ -1,5 +1,6 @@
 #!/bin/sh
-DISTRIBUTE=./dist/Ngraph
+VERSION=6.3.48
+DISTRIBUTE=./bindist/Ngraph
 if [ ! -d ${DISTRIBUTE} ]
 then
   mkdir ${DISTRIBUTE}
@@ -62,3 +63,9 @@ cp icon/Ngraph.xpm ${DISTRIBUTE}/icon
     ln -s INSTALL.jis README.jis
   fi
 )
+
+(cd ./bindist
+  mv Ngraph Ngraph-${VERSION}-linux
+  tar cvzf Ngraph-${VERSION}-linux.tar.gz ./Ngraph-${VERSION}-linux
+  mv Ngraph-${VERSION}-linux Ngraph
+)
