@@ -1,5 +1,5 @@
-/* 
- * $Id: ioutil.c,v 1.5 2003/02/16 12:42:14 isizaka Exp isizaka $
+/*
+ * $Id: ioutil.c,v 1.4 2002/07/06 08:51:42 isizaka Exp isizaka $
  * 
  * This file is part of "Ngraph for X11".
  * 
@@ -24,9 +24,6 @@
 /**
  *
  * $Log: ioutil.c,v $
- * Revision 1.5  2003/02/16 12:42:14  isizaka
- * for release 6.13.18
- *
  * Revision 1.4  2002/07/06 08:51:42  isizaka
  * change to GPL.
  *
@@ -60,7 +57,7 @@
 #endif
 #include "object.h"
 #include "nstring.h"
-#include "jstring.h"
+#include "jnstring.h"
 #include "ioutil.h"
 
 #define TRUE  1
@@ -192,7 +189,7 @@ char *getfullpath(char *name)
   char buf[MAXPATH],*s;
 
   if (name==NULL) return NULL;
-  unchangefilename(s);
+  unchangefilename(name);
   if (GetFullPathName(name,MAXPATH,buf,&s)==0) return NULL;
   if ((s=memalloc(strlen(buf)+1))==NULL) return NULL;
   strcpy(s,buf);
@@ -230,13 +227,17 @@ char *getrelativepath(char *name)
       strcpy(cwd2,cwd);
       memfree(cwd);
       i=strlen(cwd2);
-      cwd2[i]=DIRSEP;
-      cwd2[i+1]='\0';
+      if ((i==0) || (cwd2[i-1]!=DIRSEP)) {
+        cwd2[i]=DIRSEP;
+        cwd2[i+1]='\0';
+      }
       for (i=0;(cwd2[i]!='\0') && (name[i+top]!='\0');i++)
         if (cwd2[i]!=name[i+top]) break;
-      for (;cwd2[i]!=DIRSEP;i--);
+      if (i>0) i--;
+      for (;niskanji2(cwd2,i) || (cwd2[i]!=DIRSEP);i--);
       depth=0;
-      for (j=strlen(cwd2);j!=i;j--) if (cwd2[j]==DIRSEP) depth++;
+      for (j=strlen(cwd2);j!=i;j--)
+        if (!niskanji2(cwd2,j) && (cwd2[j]==DIRSEP)) depth++;
       memfree(cwd2);
       if ((s=nstrnew())==NULL) return NULL;
       if (depth==0) {
