@@ -60,7 +60,7 @@
 #include "ioutil.h"
 #include "shell.h"
 #include "nstring.h"
-#include "jstring.h"
+#include "jnstring.h"
 #include "odraw.h"
 #include "config.h"
 
@@ -882,6 +882,28 @@ int GraphSave(int overwrite)
   return ret;
 }
 
+void ToFullPath()
+{
+  struct objlist *obj;
+  int i;
+  char *file,*file2;
+
+  if ((obj=chkobject("file"))!=NULL) {
+    for (i=0;i<=chkobjlastinst(obj);i++) {
+      getobj(obj,"file",i,0,NULL,&file);
+      file2=getfullpath(file);
+      putobj(obj,"file",i,file2);
+    }
+  }
+  if ((obj=chkobject("merge"))!=NULL) {
+    for (i=0;i<=chkobjlastinst(obj);i++) {
+      getobj(obj,"file",i,0,NULL,&file);
+      file2=getfullpath(file);
+      putobj(obj,"file",i,file2);
+    }
+  }
+}
+
 void LoadNgpFile(char *File,int ignorepath,int expand,char *exdir,
                  int console,char *option)
 {
@@ -904,7 +926,6 @@ void LoadNgpFile(char *File,int ignorepath,int expand,char *exdir,
   putobj(sys,"expand_dir",0,expanddir);
   putobj(sys,"expand_file",0,&expand);
   putobj(sys,"ignore_path",0,&ignorepath);
-  ignorepath=FALSE;
   if ((obj=chkobject("shell"))==NULL) return;
   newid=newobj(obj);
   if (newid>=0) {
@@ -914,12 +935,14 @@ void LoadNgpFile(char *File,int ignorepath,int expand,char *exdir,
       if (arrayadd(&sarray,&s)==NULL) {
         memfree(s);
         arraydel2(&sarray);
+        ignorepath=FALSE;
         putobj(sys,"ignore_path",0,&ignorepath);
         return;
       }
     }
     if ((name=(char *)memalloc(strlen(File)+1))==NULL) {
       arraydel2(&sarray);
+      ignorepath=FALSE;
       putobj(sys,"ignore_path",0,&ignorepath);
       return;
     }
@@ -930,6 +953,7 @@ void LoadNgpFile(char *File,int ignorepath,int expand,char *exdir,
     if (arrayadd(&sarray,&name)==NULL) {
       memfree(name);
       arraydel2(&sarray);
+      ignorepath=FALSE;
       putobj(sys,"ignore_path",0,&ignorepath);
       return;
     }
@@ -963,6 +987,8 @@ void LoadNgpFile(char *File,int ignorepath,int expand,char *exdir,
     UpdateAll();
     delobj(obj,newid);
   }
+  if (menulocal.expandtofullpath && (!ignorepath)) ToFullPath();
+  ignorepath=FALSE;
   putobj(sys,"ignore_path",0,&ignorepath);
 }
 
