@@ -68,7 +68,7 @@
 
 #include "ngraph.h"
 #include "object.h"
-#include "jstring.h"
+#include "jnstring.h"
 #include "nstring.h"
 #include "mathfn.h"
 
